========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |requires|
        |
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|

.. |requires| image:: https://requires.io/github/mitchellpkt/python-isthmus/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/mitchellpkt/python-isthmus/requirements/?branch=master

.. |version| image:: https://img.shields.io/pypi/v/isthmuslib.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/isthmuslib

.. |wheel| image:: https://img.shields.io/pypi/wheel/isthmuslib.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/isthmuslib

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/isthmuslib.svg
    :alt: Supported versions
    :target: https://pypi.org/project/isthmuslib

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/isthmuslib.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/isthmuslib

.. |commits-since| image:: https://img.shields.io/github/commits-since/mitchellpkt/python-isthmus/v0.0.4.svg
    :alt: Commits since latest release
    :target: https://github.com/mitchellpkt/python-isthmus/compare/v0.0.4...master



.. end-badges

Misc utilities, mostly related to plotting conveniences

* Turns matplotlib.pyplot figure generation into one-liners.
* Free software for personal or academic use: **GNU Lesser General Public License v3 (LGPLv3).**
* Contact licensing@mitchellpkt.com for commercial applications.
* To-do: expand types of parameters that can be passed through (e.g. marker style, legend placement, etc).

Installation
============

::

    pip install isthmuslib

You can also install the in-development version with::

    pip install https://github.com/mitchellpkt/python-isthmus/archive/master.zip


Documentation
=============


To use the project:

.. code-block:: python

    import isthmuslib


Demo
=============
See a light demo here: https://github.com/Mitchellpkt/python-isthmuslib/blob/main/light-demo.ipynb
